@@ -211,16 +211,17 @@ class XmlElementStreamerFileInput(FileInput):
 
             # Files available: pop next file
             self.cur_file_path = self.file_list.pop(0)
-            file = open(self.cur_file_path)
+            fd = open(self.cur_file_path)
             self.elem_count = 0
             log.info("file opened : %s" % self.cur_file_path)
-            self.context = etree.iterparse(file, events=("start", "end"))
+            self.context = etree.iterparse(fd, events=("start", "end"))
             self.context = iter(self.context)
             event, self.root = self.context.next()
 
         try:
             event, elem = self.context.next()
-        except StopIteration, e:
+        except (etree.XMLSyntaxError, StopIteration):
+            # workaround for etree.XMLSyntaxError https://bugs.launchpad.net/lxml/+bug/1185701
             self.context = None
 
         if self.context is None:
